@@ -22,8 +22,8 @@ struct _clipboard_item {
   guint id; 
 };
 
-
 GtkWidget *vbox;
+GtkWidget *main_box;
 GtkWidget *applet;
 GtkWidget *copy_button;
 GtkWidget *set_selection_button;
@@ -58,6 +58,8 @@ history_menu_cb (AppletWidget *applet, gpointer data)
                              GDK_CURRENT_TIME);
   gtk_tooltips_set_tip (set_selection_tooltip, set_selection_button, 
 			clipboard.description->str, NULL);
+  return;
+  applet = NULL;
 }
 
 static void
@@ -91,10 +93,11 @@ copy_clicked_cb(GtkWidget *widget, gpointer data)
   gtk_selection_convert (widget, GDK_SELECTION_PRIMARY, targets_atom,
                          GDK_CURRENT_TIME);
   return TRUE;
+  data = NULL;
 }
 
 /* Signal handler called when the selections owner returns the data */
-void
+static void
 selection_received (GtkWidget *widget, GtkSelectionData *selection_data, 
                     gpointer data)
 {
@@ -107,6 +110,9 @@ selection_received (GtkWidget *widget, GtkSelectionData *selection_data,
 			  clipboard.description->str, NULL);
     update_history (&clipboard);
   }
+  return;
+  widget = NULL;
+  data = NULL;
 }
 
 static gint
@@ -116,6 +122,7 @@ set_selection_clicked_cb(GtkWidget *widget, gpointer data)
 	  		     GDK_SELECTION_PRIMARY,
                              GDK_CURRENT_TIME);
   return TRUE;
+  data = NULL;
 }
 
 /* sets the clipboard contents as the selection when it gets a request */
@@ -131,9 +138,14 @@ clipboard_selection_handler(GtkWidget *widget,
 			 8,
 			 clipboard.clipboard_data->str,
 			 clipboard.clipboard_data->len);
+  return;
+  widget = NULL;
+  info = 0;
+  time = 0;
+  data = NULL;
 }
 
-GtkWidget *
+static GtkWidget *
 button_new_with_xpm(GtkWidget *parent, gchar **xpm)
 {
   GtkWidget *button;
@@ -170,6 +182,85 @@ about (AppletWidget *applet, gpointer data)
 			       NULL);
   gtk_window_set_modal (GTK_WINDOW(about_box),TRUE);
   gnome_dialog_run (GNOME_DIALOG (about_box));
+  return;
+  applet = NULL;
+  data = NULL;
+}
+
+static void
+relayout (gboolean vertical)
+{
+	gtk_widget_ref (copy_button);
+	gtk_widget_ref (set_selection_button);
+
+	gtk_container_remove (GTK_CONTAINER (main_box), copy_button);
+	gtk_container_remove (GTK_CONTAINER (main_box), set_selection_button);
+	gtk_widget_destroy (main_box);
+
+	if (vertical)
+		main_box = gtk_vbox_new(TRUE, 0);
+	else
+		main_box = gtk_hbox_new(TRUE, 0);
+	gtk_widget_show (main_box);
+	gtk_box_pack_start(GTK_BOX (vbox), main_box, TRUE, TRUE, 0);
+
+	gtk_box_pack_start(GTK_BOX (main_box), copy_button, TRUE, TRUE, 0);
+
+	gtk_box_pack_start(GTK_BOX (main_box), set_selection_button, TRUE, TRUE, 0);
+
+	gtk_widget_unref (copy_button);
+	gtk_widget_unref (set_selection_button);
+}
+
+/*this is when the panel orientation changes*/
+static void
+applet_change_orient (GtkWidget *w, PanelOrientType o, gpointer data)
+{
+	int size = applet_widget_get_panel_pixel_size (APPLET_WIDGET (applet));
+	switch(o) {
+	case ORIENT_UP: 
+	case ORIENT_DOWN:
+		if(size<48)
+			relayout (FALSE);
+		else
+			relayout (TRUE);
+		break;
+	case ORIENT_LEFT:
+	case ORIENT_RIGHT:
+		if(size<48)
+			relayout (TRUE);
+		else
+			relayout (FALSE);
+		break;
+	}
+	return;
+	w = NULL;
+	data = NULL;
+}
+
+static void
+applet_change_pixel_size (GtkWidget *w, int size, gpointer data)
+{
+	PanelOrientType o = applet_widget_get_panel_orient (APPLET_WIDGET (applet));
+	switch(o) {
+	case ORIENT_UP: 
+	case ORIENT_DOWN:
+		if(size<48)
+			relayout (FALSE);
+		else
+			relayout (TRUE);
+		break;
+	case ORIENT_LEFT:
+	case ORIENT_RIGHT:
+		if(size<48)
+			relayout (TRUE);
+		else
+			relayout (FALSE);
+		break;
+	}
+	return;
+	w = NULL;
+	data = NULL;
 }
 
 int
@@ -199,16 +290,21 @@ main(int argc, char **argv)
   
   /* create the vbox */
   vbox = gtk_vbox_new(TRUE, 0);
+  main_box = gtk_vbox_new(TRUE, 0);
+  gtk_box_pack_start(GTK_BOX (vbox), main_box, TRUE, TRUE, 0);
   /* create, attach signal to, and pack the buttons */
 
-  copy_button = button_new_with_xpm(vbox, copy_xpm);
+  /* realize the applet so that we may get the xpms */
+  gtk_widget_realize (applet);
+
+  copy_button = button_new_with_xpm(applet, copy_xpm);
   gtk_signal_connect (GTK_OBJECT (copy_button), "clicked",
                       GTK_SIGNAL_FUNC (copy_clicked_cb), NULL);
   gtk_signal_connect (GTK_OBJECT(copy_button), "selection_received",
                       GTK_SIGNAL_FUNC (selection_received), NULL);
-  gtk_box_pack_start(GTK_BOX (vbox), copy_button, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX (main_box), copy_button, TRUE, TRUE, 0);
 
-  set_selection_button = button_new_with_xpm(vbox, set_selection_xpm);
+  set_selection_button = button_new_with_xpm(applet, set_selection_xpm);
   gtk_signal_connect (GTK_OBJECT (set_selection_button), "clicked",
                       GTK_SIGNAL_FUNC (set_selection_clicked_cb), NULL);
   gtk_selection_add_target (set_selection_button, 
@@ -219,9 +315,16 @@ main(int argc, char **argv)
 		      GTK_SIGNAL_FUNC (clipboard_selection_handler),
 		      NULL);
 
-  gtk_box_pack_start(GTK_BOX (vbox), set_selection_button, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX (main_box), set_selection_button, TRUE, TRUE, 0);
   gtk_widget_show_all(vbox);
 
+  gtk_signal_connect(GTK_OBJECT(applet),"change_pixel_size",
+		     GTK_SIGNAL_FUNC(applet_change_pixel_size),
+		     NULL);
+  gtk_signal_connect(GTK_OBJECT(applet),"change_orient",
+		     GTK_SIGNAL_FUNC(applet_change_orient),
+		     NULL);
+
   /* connect up the about box */
   applet_widget_register_stock_callback (APPLET_WIDGET (applet),
 				         "about",
