@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.10 2000/01/29 03:24:21 tgil Exp $ */
+/* $Id: gweather-applet.c,v 1.12 2000/02/09 04:36:01 spapadim Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -44,6 +44,8 @@ static GtkTooltips *tooltips = NULL;
 static PanelOrientType gweather_orient = ORIENT_DOWN;
 #ifdef HAVE_PANEL_PIXEL_SIZE
 static int gweather_size = PIXEL_SIZE_STANDARD;
+#else /* HAVE_PANEL_PIXEL_SIZE */
+static int gweather_size;
 #endif /* HAVE_PANEL_PIXEL_SIZE */
 
 /* FIX - This code is WAY too kludgy!... */
@@ -108,7 +110,7 @@ static void change_pixel_size_cb (AppletWidget *w, int s)
     gweather_size = s;
     place_widgets();
     return;
-    w = NULL;
+    w = NULL;  /* Hush warnings */
 }
 #endif /* HAVE_PANEL_PIXEL_SIZE */
 
@@ -143,6 +145,14 @@ static void about_cb (AppletWidget *widget, gpointer data)
     data = NULL;
 }
 
+static void help_cb (AppletWidget *applet, gpointer data)
+{
+    static GnomeHelpMenuEntry help_entry = { NULL, "index.html"};
+
+    help_entry.name = gnome_app_id;
+    gnome_help_display(NULL, &help_entry);
+}
+
 static void pref_cb (AppletWidget *widget, gpointer data)
 {
     gweather_pref_run();
@@ -174,6 +184,9 @@ void gweather_applet_create (int argc, char *argv[])
     applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), "about",
                                            GNOME_STOCK_MENU_ABOUT, _("About..."),
                                            about_cb, NULL);
+    applet_widget_register_callback (APPLET_WIDGET(gweather_applet), "help",
+                                     _("Help"),
+                                     help_cb, NULL);
     applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), "preferences",
                                            GNOME_STOCK_MENU_PREF, _("Properties..."),
                                            pref_cb, NULL);
