@@ -38,19 +38,19 @@
 
 GtkWidget *applet;
 
-static gint appletDestroy_signal(GtkWidget *widget, gpointer data);
-static gint appletDetached_signal(GtkWidget *widget, gpointer data);
-static gint appletAttached_signal(GtkWidget *widget, gpointer data);
+static gint applet_destroy_signal(GtkWidget *widget, gpointer data);
+static gint applet_detached_signal(GtkWidget *widget, gpointer data);
+static gint applet_attached_signal(GtkWidget *widget, gpointer data);
 static gint applet_orient_changed_cb(GtkWidget *widget, gpointer data);
 #ifdef HAVE_PANEL_PIXEL_SIZE
 static void applet_pixel_size_changed_cb(GtkWidget *widget, int size, gpointer data);
 #endif
 
 static gint
-appletDestroy_signal(GtkWidget *widget, gpointer data)
+applet_destroy_signal(GtkWidget *widget, gpointer data)
 {
     /* applet will be destroyed; save settings now */
-    saveSession();
+    save_session();
     /* go on */
     return FALSE;  
     widget = NULL;
@@ -58,13 +58,13 @@ appletDestroy_signal(GtkWidget *widget, gpointer data)
 }
 
 static gint
-appletDetached_signal(GtkWidget *widget, gpointer data)
+applet_detached_signal(GtkWidget *widget, gpointer data)
 {
     /* applet has been detached; make it smaller */
 
     gtk_widget_set_usize(GTK_WIDGET(applet),
 			 20,
-			 prop.normalSizeY);
+			 prop.normal_size_y);
   
     /* go on */
     return FALSE;  
@@ -73,13 +73,13 @@ appletDetached_signal(GtkWidget *widget, gpointer data)
 }
 
 static gint
-appletAttached_signal(GtkWidget *widget, gpointer data)
+applet_attached_signal(GtkWidget *widget, gpointer data)
 {
     /* applet has been detached; restore original size */
 
     gtk_widget_set_usize(GTK_WIDGET(applet),
-			 prop.normalSizeX,
-			 prop.normalSizeY);
+			 prop.normal_size_x,
+			 prop.normal_size_y);
   
     /* go on */
     return FALSE;  
@@ -93,7 +93,7 @@ applet_orient_changed_cb(GtkWidget *widget, gpointer data)
     static int counter = 0;
 
     if(counter++ > 0)
-	showMessage((gchar *) _("orient. changed")); 
+	show_message((gchar *) _("orient. changed")); 
 
     /* go on */
     return FALSE;  
@@ -109,16 +109,24 @@ applet_pixel_size_changed_cb(GtkWidget *widget, int size, gpointer data)
     static int counter = 0;
 
     if(counter++ > 0)
-	showMessage((gchar *) _("size changed")); 
+	show_message((gchar *) _("size changed")); 
 
-    prop.normalSizeY = size;
-    if(size<PIXEL_SIZE_STANDARD) {
-	    prop.showFrame = FALSE;
-	    prop.flatLayout = TRUE;
-    } else {
-	    prop.showFrame = TRUE;
-	    prop.flatLayout = FALSE;
-    }
+    prop.normal_size_y = size;
+    if(size <= PIXEL_SIZE_TINY)
+	{
+	    prop.show_frame = FALSE;
+	    prop.flat_layout = TRUE;
+	} 
+    else if(size <= PIXEL_SIZE_SMALL)
+	{
+	    prop.show_frame = TRUE;
+	    prop.flat_layout = TRUE;
+	} 
+    else
+	{
+	    prop.show_frame = TRUE;
+	    prop.flat_layout = FALSE;
+	}
 
     redraw_applet();
     return;
@@ -130,7 +138,7 @@ applet_pixel_size_changed_cb(GtkWidget *widget, int size, gpointer data)
 void
 redraw_applet(void)
 {
-    GtkWidget *hbox, *hboxButtons;
+    GtkWidget *hbox, *hbox_buttons;
     GtkWidget *button;
     GtkWidget *frame;
     GtkWidget *frame2;
@@ -145,13 +153,13 @@ redraw_applet(void)
     static int first_time = TRUE;   
 
     /* recalculate sizes */
-    if(prop.showHandle)
+    if(prop.show_handle)
 	size_frames += 0;
-    if(prop.showFrame)
+    if(prop.show_frame)
 	size_frames += 6;
-    if(prop.flatLayout) 
+    if(prop.flat_layout) 
 	size_status_line = 0;
-    prop.cmdLineY = prop.normalSizeY - size_status_line - size_frames;   
+    prop.cmd_line_size_y = prop.normal_size_y - size_status_line - size_frames;   
 
     if(!applet_vbox)
 	{
@@ -172,13 +180,13 @@ redraw_applet(void)
 
     /*
 
-      GtkStyle *style;
-      style = malloc(sizeof(GtkStyle));
-      style->bg_pixmap[GTK_STATE_NORMAL] = bgPixmap;
+      Gtk_style *style;
+      style = malloc(sizeof(Gtk_style));
+      style->bg_pixmap[GTK_STATE_NORMAL] = bg_pixmap;
       gtk_widget_push_style (style);
     */
     
-    if(prop.flatLayout) 
+    if(prop.flat_layout) 
 	vbox = gtk_hbox_new(FALSE, 0);
     else
 	vbox = gtk_vbox_new(FALSE, 0);
@@ -186,31 +194,31 @@ redraw_applet(void)
     
     /* add command line; position: top */
     if(1)
-	initCommandEntry();
+	init_command_entry();
     else
 	terminal_init();
 
-/*     gtk_box_pack_start(GTK_BOX(vbox), entryCommand, FALSE, FALSE, 0); */
+/*     gtk_box_pack_start(GTK_BOX(vbox), entry_command, FALSE, FALSE, 0); */
 
     /* hbox for message label and buttons */
     hbox = gtk_hbox_new(FALSE, 0);
     
     /* add message label */
-    initMessageLabel();
+    init_message_label();
 
     /* do not center text but put it to bottom instead */
-    gtk_misc_set_alignment(GTK_MISC(labelMessage), 0.0, 1.0);
-    gtk_box_pack_start(GTK_BOX(hbox), labelMessage, TRUE, TRUE, 0);
+    gtk_misc_set_alignment(GTK_MISC(label_message), 0.0, 1.0);
+    gtk_box_pack_start(GTK_BOX(hbox), label_message, TRUE, TRUE, 0);
 
-    if(prop.flatLayout) 
-	hboxButtons = gtk_vbox_new(TRUE, 0);
+    if(prop.flat_layout) 
+	hbox_buttons = gtk_vbox_new(TRUE, 0);
     else
-	hboxButtons = gtk_hbox_new(TRUE, 0);
+	hbox_buttons = gtk_hbox_new(TRUE, 0);
 
     /* add file-browser button */
     button = gtk_button_new();
     gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		       GTK_SIGNAL_FUNC(showFileBrowser_signal),
+		       GTK_SIGNAL_FUNC(show_file_browser_signal),
 		       NULL);
     gtk_widget_set_usize(GTK_WIDGET(button), 13, 10);
     icon = gnome_pixmap_new_from_xpm_d (browser_mini_xpm);
@@ -218,12 +226,12 @@ redraw_applet(void)
     applet_widget_set_widget_tooltip(APPLET_WIDGET(applet),
 				     GTK_WIDGET(button),
 				     _("Browser"));
-    gtk_box_pack_start(GTK_BOX(hboxButtons), button, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(hbox_buttons), button, TRUE, TRUE, 0);
 
     /* add history button */
     button = gtk_button_new();
     gtk_signal_connect(GTK_OBJECT(button), "button_press_event",
-		       GTK_SIGNAL_FUNC(showHistory_signal),
+		       GTK_SIGNAL_FUNC(show_history_signal),
 		       NULL);
     gtk_widget_set_usize(GTK_WIDGET(button), 13, 10);
     icon = gnome_pixmap_new_from_xpm_d (history_mini_xpm);
@@ -231,21 +239,21 @@ redraw_applet(void)
     applet_widget_set_widget_tooltip(APPLET_WIDGET(applet),
 				     GTK_WIDGET(button),
 				     _("History"));
-    gtk_box_pack_end(GTK_BOX(hboxButtons), button, TRUE, TRUE, 0);
+    gtk_box_pack_end(GTK_BOX(hbox_buttons), button, TRUE, TRUE, 0);
 
     /* add buttons into frame */
     frame = gtk_frame_new(NULL);
     gtk_container_set_border_width(GTK_CONTAINER(frame), 1);
     gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-    gtk_container_add(GTK_CONTAINER(frame), hboxButtons);
+    gtk_container_add(GTK_CONTAINER(frame), hbox_buttons);
     gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 0);
 
     /* put message label and history/file-browser button into vbox */
     gtk_box_pack_end(GTK_BOX(vbox), hbox, TRUE, TRUE, 0);
 
-    if (prop.showHandle)
+    if (prop.show_handle)
 	{
-	    if (prop.showFrame)
+	    if (prop.show_frame)
 		{
 		    /* inner frame */
 		    frame = gtk_frame_new(NULL);
@@ -257,17 +265,17 @@ redraw_applet(void)
 	       panel */
 	    handle = gtk_handle_box_new();
 	    gtk_signal_connect(GTK_OBJECT(handle), "child_detached",
-			       GTK_SIGNAL_FUNC(appletDetached_signal),
+			       GTK_SIGNAL_FUNC(applet_detached_signal),
 			       NULL);
 	    gtk_signal_connect(GTK_OBJECT(handle), "child_attached",
-			       GTK_SIGNAL_FUNC(appletAttached_signal),
+			       GTK_SIGNAL_FUNC(applet_attached_signal),
 			       NULL);
-	    if (prop.showFrame)
+	    if (prop.show_frame)
 		gtk_container_add(GTK_CONTAINER(handle), frame);
 	    else
 		gtk_container_add(GTK_CONTAINER(handle), vbox);
 	    
-	    if (prop.showFrame)
+	    if (prop.show_frame)
 		{
 		    /* outer frame */
 		    frame2 = gtk_frame_new(NULL);
@@ -278,14 +286,14 @@ redraw_applet(void)
 	    /* there was trouble with the tooltip */
 	    /* applet_widget_set_tooltip(APPLET_WIDGET(applet),  _("Mini-Commander")); */
 	    
-	    if (prop.showFrame)
+	    if (prop.show_frame)
 		gtk_box_pack_start(GTK_BOX(applet_inner_vbox), frame2, TRUE, TRUE, 0);
 	    else
 		gtk_box_pack_start(GTK_BOX(applet_inner_vbox), handle, TRUE, TRUE, 0);
 	} 
     else 
 	{
-	    if (prop.showFrame)
+	    if (prop.show_frame)
 		{
 		    /* inner frame */
 		    frame = gtk_frame_new(NULL);
@@ -309,20 +317,19 @@ redraw_applet(void)
 	applet_widget_add (APPLET_WIDGET (applet), applet_vbox);
     first_time = FALSE;
 
-    gtk_widget_set_usize(GTK_WIDGET(applet), prop.normalSizeX, prop.normalSizeY);
+    gtk_widget_set_usize(GTK_WIDGET(applet), prop.normal_size_x, prop.normal_size_y);
 
     /* allow pasting into the input box by packing it after
        applet_widdget_add has bound the middle mouse button (idea taken
-       from the applet WebControl by Garrett Smith) */
-    if(1)
-	gtk_box_pack_start(GTK_BOX(vbox), entryCommand, FALSE, FALSE, 0);
-    else
-	{
-	    frame = gtk_frame_new(NULL);
-	    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-	    gtk_container_add(GTK_CONTAINER(frame), terminal_zvt);
-	    gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	}	
+       from the applet Web_control by Garrett Smith) */
+#if 1
+    gtk_box_pack_start(GTK_BOX(vbox), entry_command, FALSE, FALSE, 0);
+#else
+    frame = gtk_frame_new(NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
+    gtk_container_add(GTK_CONTAINER(frame), terminal_zvt);
+    gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
+#endif
 
     gtk_widget_show_all(applet_vbox);
     gtk_widget_show_all(applet_inner_vbox);
@@ -335,7 +342,7 @@ int
 main(int argc, char **argv)
 {
     /* install signal handler */
-    initExecSignalHandler();
+    init_exec_signal_handler();
     
     /* initialize the i18n stuff */
     bindtextdomain (PACKAGE, GNOMELOCALEDIR);
@@ -370,16 +377,16 @@ main(int argc, char **argv)
 		       NULL);
 #endif
     
-    loadSession();
+    load_session();
     
     gtk_signal_connect(GTK_OBJECT(applet), "destroy",
-		       (GtkSignalFunc) appletDestroy_signal,
+		       (GtkSignalFunc) applet_destroy_signal,
 		       NULL); 
     
     /* bind the session save signal */
     gtk_signal_connect(GTK_OBJECT(applet),
 		       "save_session",
-		       GTK_SIGNAL_FUNC(saveSession_signal),
+		       GTK_SIGNAL_FUNC(save_session_signal),
 		       NULL);
 
     redraw_applet();
@@ -389,23 +396,23 @@ main(int argc, char **argv)
 					  "properties",
 					  GNOME_STOCK_MENU_PROP,
 					  _("Properties..."),
-					  propertiesBox,
+					  properties_box,
 					  NULL);
     
     applet_widget_register_callback(APPLET_WIDGET(applet),
 				    "help",
 				    _("Help"),
-				    showHelp,
+				    show_help,
 				    NULL);
 
     applet_widget_register_stock_callback(APPLET_WIDGET(applet),
 					  "about",
 					  GNOME_STOCK_MENU_ABOUT,
 					  _("About..."),
-					  aboutBox,
+					  about_box,
 					  NULL);
       
-    showMessage((gchar *) _("ready...")); 
+    show_message((gchar *) _("ready...")); 
  
     /* special corba main loop */
     applet_widget_gtk_main ();
