@@ -91,8 +91,12 @@ openMixer( gchar *device_name )
 	mixerfd = open(device_name, O_RDWR, 0);
 	if (mixerfd < 0) {
 		/* probably should die more gracefully */
-		g_message(_("Couldn't open mixer device %s\n"),device_name);
-		exit(1);
+		char *s = g_strdup_printf(_("Couldn't open mixer device %s\n"),
+					  device_name);
+		gnome_error_dialog(s);
+		g_warning(s);
+		g_free(s);
+		return;
 	}
 
         /*
@@ -113,6 +117,9 @@ readMixer(void)
 {
 	gint vol, r, l;
 
+	/* if we couldn't open the mixer */
+	if (mixerfd < 0) return 0;
+
 	ioctl(mixerfd, MIXER_READ(SOUND_MIXER_VOLUME), &vol);
 
 	l = vol & 0xff;
@@ -127,6 +134,9 @@ setMixer(gint vol)
 {
 	gint tvol;
 
+	/* if we couldn't open the mixer */
+	if (mixerfd < 0) return;
+
 	tvol = (vol << 8) + vol;
 /*g_message("Saving mixer value of %d",tvol);*/
 	ioctl(mixerfd, MIXER_WRITE(SOUND_MIXER_VOLUME), &tvol);
@@ -136,6 +146,8 @@ static void
 free_data(GtkWidget * widget, gpointer data)
 {
 	g_free(data);
+	return;
+	widget = NULL;
 }
 
 static void 
@@ -219,6 +231,7 @@ mixer_timeout_callback(gpointer data)
 	(*md->update_func) (mixerw, mvol);
 
 	return 1;
+	data = NULL;
 }
 
 static void
@@ -372,11 +385,11 @@ create_computer_mixer_widget(GtkWidget ** mixer,
         gtk_scale_set_draw_value(GTK_SCALE(vscale), FALSE);
         gtk_scale_set_draw_value(GTK_SCALE(hscale), FALSE);
 
-	gtk_widget_set_usize(GTK_WIDGET(vscale), 18, 32);
-	gtk_widget_set_usize(GTK_WIDGET(hscale), 36, 20);
+	gtk_widget_set_usize(GTK_WIDGET(vscale), 20, 32);
+	gtk_widget_set_usize(GTK_WIDGET(vbutton),20, 15);
 
-	gtk_widget_set_usize(GTK_WIDGET(vbutton),12 , 15);
-	gtk_widget_set_usize(GTK_WIDGET(hbutton),12 , 20);
+	gtk_widget_set_usize(GTK_WIDGET(hscale), 32, 20);
+	gtk_widget_set_usize(GTK_WIDGET(hbutton),15, 20);
 
 	
 	/* pack the widgets */
@@ -484,7 +497,7 @@ create_computer_mixer_widget(GtkWidget ** mixer,
 }
 
 static void
-	start_gmix_cb()
+start_gmix_cb()
 {
 	gnome_execute_shell(NULL, "gmix");
 }
@@ -494,6 +507,9 @@ destroy_mixer(GtkWidget * widget, void *data)
 {
 	gtk_timeout_remove(md->timeout);
 	g_free(md);
+	return;
+	widget = NULL;
+	data = NULL;
 }
 
 static GtkWidget *
@@ -619,10 +635,11 @@ main(int argc, char **argv)
 	bindtextdomain(PACKAGE, GNOMELOCALEDIR);
 	textdomain(PACKAGE);
 
-	openMixer("/dev/mixer");
 	applet_widget_init("mixer_applet", VERSION, argc, argv,
 				    NULL, 0, NULL);
 
+	openMixer("/dev/mixer");
+
 	applet = applet_widget_new("mixer_applet");
 	if (!applet)
 		g_error(("Can't create applet!\n"));
